@@ -20,6 +20,9 @@ def serve(
     ),
     max_num_seq: int = typer.Option(2, help="The maximum number of sequences."),
     max_model_len: int = typer.Option(4096, help="The maximum model length."),
+    gpu_memory_utilization: float = typer.Option(
+        0.98, help="The GPU memory utilization."
+    ),
 ):
     from mw_python_sdk.llm.inference import serve
 
@@ -31,6 +34,7 @@ def serve(
         max_num_seq=max_num_seq,
         max_model_len=max_model_len,
         tensor_parallel_size=parallal_size,
+        gpu_memory_utilization=gpu_memory_utilization,
         quantization=quantization,
         load_format=load_format,
         enforce_eager=enforce_eager,
