@@ -12,6 +12,20 @@ from mw_python_sdk import download_dir, download_file, upload_file
 # --quantization bitsandbytes --load-format bitsandbytes --enforce-eager
 
 
+def get_gpu_count():
+    # Get the value of NVIDIA_VISIBLE_DEVICES environment variable
+    visible_devices = os.getenv("NVIDIA_VISIBLE_DEVICES", "")
+
+    if not visible_devices:
+        raise ValueError("NVIDIA_VISIBLE_DEVICES is not set or empty.")
+
+    # The environment variable can be a comma-separated list of GPU indices or UUIDs.
+    # Count the number of items in the list
+    gpu_count = len(visible_devices.split(","))
+
+    return gpu_count
+
+
 def get_first_gpu_type():
     # Run the nvidia-smi command to get GPU info
     result = subprocess.run(
@@ -30,15 +44,17 @@ def get_first_gpu_type():
 
     return gpu_type
 
+
 def serve(
     model_id: str,
     model_name: str,
     host: str = "127.0.0.1",
     port: int = 8080,
     dtype: str = "auto",
-    max_model_len: int = 4096,
-    max_num_seq: int = 2,
-    tensor_parallel_size: int = 1,
+    max_model_len: int = 1024,
+    max_num_seq: int = 10,
+    tensor_parallel_size: int = 0,
+    gpu_memory_utilization: float = 0.98,
     quantization: Optional[str] = None,
     load_format: Optional[str] = None,
     enforce_eager: bool = False,
@@ -55,6 +71,8 @@ def serve(
         gpu_type = get_first_gpu_type()
         if "V100" in gpu_type:
             dtype = "half"
+        if tensor_parallel_size == 0:
+            tensor_parallel_size = get_gpu_count()
         # quantization
         extra_arguments = ""
         if quantization:
